__author__ = 'jpratt'
import re
import sys

import pymongo


def get_regex_value(match, index, default_value=None):
    try:
        return match.group(index) or default_value
    except:
        if default_value:
            return default_value
        else:
            return "not_found_in_config"

def add_mongo_parser_arguments(config, parser):
    mongo_username = get_regex_value(re.search('moab.mongo.username(.*?)=(.*?)"(.*?)"', config), 3, 'moab_user')
    mongo_password = get_regex_value(re.search('moab.mongo.password(.*?)=(.*?)"(.*?)"', config), 3, 'secret2')
    mongo_host = get_regex_value(re.search('moab.mongo.host(.*?)=(.*?)"(.*?)"', config), 3, 'localhost')
    mongo_port = int(get_regex_value(re.search('moab.mongo.port(.*?)=\s*(\d*) ', config), 2, '27017'))
    mongo_database_name = get_regex_value(re.search('moab.mongo.databaseName(.*?)=(.*?)"(.*?)"', config), 3, 'moab')

    parser.add_argument('--mongo-database-name',
                        default=mongo_database_name,
                        help="The MongoDB database name to use"
                        )
    parser.add_argument('--mongo-username',
                        default=mongo_username,
                        help="The username to use when connecting to MongoDB"
                        )
    parser.add_argument('--mongo-password',
                        default=mongo_password,
                        help="The password to use when connecting to MongoDB"
                        )
    parser.add_argument('--mongo-host',
                        default=mongo_host,
                        help="The MongoDB host to use"
                        )
    parser.add_argument('--mongo-port',
                        default=mongo_port,
                        help="The MongoDB port to use"
                        )
    return parser


def get_job_from_mongo(moab, job_name, logger):
    try:
        job = moab.job.find({'name': job_name}, {'requirements.features':1, 'requirements.metrics':1,'requirements.resourcesPerTask':1, 'requirements.architecture':1, 'requirements.taskCount':1, 'requirements.image':1, 'requirements.tasksPerNode':1, '_id':0,'name':1})[0]
    except:
        return None
    if job:
        logger.debug("Job details: %s" % job)
    else:
        logger.error("Could not retrieve job information from moab mongo")
    return job

class MongoConnection():
    def __init__(self, args, logger):
        self.client = pymongo.MongoClient(args.mongo_host, args.mongo_port)
        self.insight = self.client[args.mongo_database_name]
        if args.mongo_username:
            try:
                self.insight.authenticate(args.mongo_username, args.mongo_password)
                self.connected = True
            except:
                logger.error("Mongo authentication failed for user '%s' to database '%s' on host '%s:%s'" % (
                    args.mongo_username,
                    args.mongo_database_name,
                    args.mongo_host,
                    args.mongo_port))
                self.connected = False

    def withConnection(self, action, arg1=None, arg2=None):
        try:
            return action(self.insight, arg1, arg2)
        finally:
            self.client.close()
