#! /usr/bin/perl -w
################################################################################
#
# Feb 7, 2006
#
# Usage: ipmi.mon.pl
#
# This script is used to retrieve IPMI sensor data from cluster nodes.
# The script checks to see if the IPMI daemon is running and
# if it's not, it starts it and returns.  If it is running, it outputs
# the contents of ipmicache.gm to STDOUT and returns.
#
#   Copyright (C) 2005-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.
#
################################################################################
use strict;
use FindBin;
use lib "/make_install/lib/perl5", "/make_install/etc";             # Installed
use lib "${FindBin::Bin}/../../lib/perl5", "${FindBin::Bin}/../../etc";   # Configured
use Moab::Tools;    # Required before including config to set $homeDir
BEGIN { require "$FindBin::Bin/config.ipmi.pl"; }
#use Data::Dumper;
our ($homeDir, $daemon, $ipmifile);

# Check to see if the daemon is running
my $lines = `ps -ef | grep $daemon | grep start | grep -v grep | wc -l`;
chomp $lines;

# If not, run __ipmi.pl to update the files and then start up the daemon
unless ($lines)
{
    system "$FindBin::Bin/$daemon" and die "Monitor failed: " . ($? >> 8) . "\n";
    system "$FindBin::Bin/$daemon --start >/dev/null"
      and die "Monitor daemon failed to start: " . ($? >> 8) . "\n";
}

# Print the contents of the ipmi spool to STDOUT
open(INFILE, "${homeDir}/spool/$ipmifile") or die("No file $ipmifile\n");
while( my $line = <INFILE>)
{ 
	print "$line"; 
}
close(INFILE);
1;

__END__

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head2 EXPORT

=head2 EXPORT_OK

=head1 SEE ALSO

Additional information can be found at http://www.adaptivecomputing.com/

=head1 AUTHOR

Adaptive Computing, Inc., E<lt>http://www.adaptivecomputing.com/E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2005-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.

=cut
