#! /usr/bin/perl -w
################################################################################
#
# Usage: ipmi.power.pl
#
# This script is used to node power state via IPMI.
#
#   Copyright (C) 2005-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.
#
################################################################################
use strict;
use FindBin;
use lib "/make_install/lib/perl5", "/make_install/etc";             # Installed
use Moab::Tools;    # Required before including config to set $homeDir
BEGIN { require "$FindBin::Bin/config.ipmi.pl"; }
use Data::Dumper;
our ($homeDir, $ipmiuser, $ipmipass, $bmcaddrmap);

my $innode = $ARGV[0];
my $stat = $ARGV[1];
my $upd;
my %bmcip;

if ( $#ARGV ne 1 )
{
	print "ERROR: Expected following arguments: <node> <status>\n";
	exit 1;
}

# Generate BMC IP address mapping hash
open(BMCADDR,"${homeDir}/$bmcaddrmap");
while( my $line = <BMCADDR>)
{
        chomp($line);
        if ($line !~ /#/)
        {
                my @bmcinfo = split(/\s+/,$line);
                $bmcip{$bmcinfo[0]} = $bmcinfo[1];
        }
}
close(BMCADDR);

# Check if requested node is in BMP IP hash
if ( not exists $bmcip{$innode} )
{
	print "ERROR: Requested node $innode does not have associated BMC IP address.  Add to $bmcaddrmap.\n";
	exit 1;
}

# Convert to lowercase
$stat =~ tr/A-Z/a-z/;

# Check status modifier
if ( $stat =~ "reboot" )
{
	$stat = "reset";
}

if ( $stat !~ "reset" && $stat !~ "on" && $stat !~ "off" )
{
	print "ERROR: Requested state: $stat is not valid\n";
	exit 1;
}

# Run the change of status IPMI command
system "ipmitool -I lan -H $bmcip{$innode} -U \"$ipmiuser\" -P \"$ipmipass\" chassis power $stat";

open(TMPFILE,">>tmppowerfile.txt");
print TMPFILE `date`;
print TMPFILE "args: $ARGV[0] $ARGV[1]\n";
print TMPFILE "ipmitool -I lan -H $bmcip{$innode} -U \"$ipmiuser\" -P \"$ipmipass\" chassis power $stat\n";
print TMPFILE "\n";
close TMPFILE;

exit $?;
1;

__END__

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head2 EXPORT

=head2 EXPORT_OK

=head1 SEE ALSO

Additional information can be found at http://www.adaptivecomputing.com/

=head1 AUTHOR

Adaptive Computing, Inc., E<lt>http://www.adaptivecomputing.com/E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2005-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.

=cut
