#! /usr/bin/perl -w
################################################################################
#
# Name:         {pro|epi}logue.user
#
# Description:  This file can double as a prologue.user or epilogue.user
#               and is used to implement a personal prologue or epilogue
#               passed to the job via -l {pro|epi}logue=<filename>.
#
#   Copyright (C) 2010-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.
#
################################################################################
use strict;

my ($jobId, $scriptType);
if ($0 =~ /((?:pro|epi)logue).user/) { $scriptType = $1; }
$jobId = shift;
if (defined $scriptType && defined $jobId)
{
    my ($scriptName);

    # Parse personal {pro|epi}logue name out of qstat -f <job_id>
    my $cmd = "qstat -f $jobId";
    my $output = `$cmd 2>&1`;
    my $rc     = $? >> 8;
    die "Subcommand ($cmd) failed with rc=$rc:\n$output" if $rc;
    my @lines = split /\n/, $output;
    while (defined(my $line = shift @lines))
    {
        # Parse {pro|epi}logue script
        if ($line =~ /Resource_List.${scriptType} = (\S*)/)
        {
            $scriptName = $1;
        }
    }

    # Execute {pro|epi}logue script
    if (defined $scriptName && -x $scriptName)
    {
        print "Executing personal $scriptType: $scriptName\n";
        print `$scriptName`;
        exit $? if $?;
    }
}

exit 0;
1;
__END__

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head2 EXPORT

=head2 EXPORT_OK

=head1 SEE ALSO

Additional information can be found at http://www.adaptivecomputing.com/

=head1 AUTHOR

Adaptive Computing, Inc., E<lt>http://www.adaptivecomputing.com/E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2010-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.

=cut
