#!/bin/bash
#
#   Copyright (C) 2010-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.
#

# This file can double as a prologue.user or epilogue.user.
# Rename this file according to the desired use.

# The following code looks for a personal prologue or epilogue specification
# in the qstat -f output and runs the specified script as appropriate.

ME=`echo $0 | sed -n 's:\(.*/\)\([^/]\+\):\2:g;p'`

`echo \"$0\" \"$1\" \"$LSB_JOBID\" >> /tmp/DEBUG`

if [ "$ME" = "prologue.user" ]; then
  STYPE="prologue"
elif [ "$ME" = "epilogue.user" ] ; then
  STYPE="epilogue"
else 
  echo "invoked from unexpected file name \"$ME\""
  exit 1
fi

if [ $# -eq 0 ]; then
  if [ ! $LSB_JOBID = "" ]; then
    SNAME="$LSB_JOBID"
  else 
    echo "could not determine job name, exiting"
    exit 2 
  fi
elif [ $# -eq 1 ]; then
  SNAME="$1"
else 
  echo "usage: $0 [process name]"
  exit 3
fi

SCRIPT=$(qstat -f | sed -n ' 
  /^Job Id: \(.*\)/ {
    # extract the job ID
    s/^Job Id: \(.*\)/\1/

    # clear leading and trailing space
    s/^\s\+//g
    s/\s\+$//g

    # copy to hold buffer
    h
  }

  /^\s\+Resource_List.\(pro\|epi\)logue\s*=\s*.\+/ {
    # clear leading and trailing space
    s/^\s\+//g
    s/\s\+$//g

    # append the resource list AVP to the pattern buffer
    s/^\s\+//g
    H

    # copy [Job Id]\n[Resource_List] to the hold buffer
    x;h

    # change the pattern buffer to the desired format
    s/\n/ /g

    # check for expected job name and pro/epi-logueness
    /'$1' Resource_List\.'$STYPE' = \(.\+\)/ {
      s/'$1' Resource_List\.'$STYPE' = \(.\+\)/\1/
      p 
      q
    }
    
    # restore the hold buffer to its original state
    x
    s/\(.*\)\n.*/\1/ 
    x
  }

')

if [ -f $SCRIPT ]; then
  `$SCRIPT`
  exit $?
fi

exit 0
