#! /usr/bin/perl -w
################################################################################
#
# Usage: jobs4nodes "perl5 regular expression pattern"
#
# This script is used to list jobids with a particular nodes pattern
#
#   Copyright (C) 2010-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.
#
################################################################################
use strict;

# Parse Command Line Arguments
die "Usage: $0 <nodes expression (perl5regex)>\n" unless @ARGV == 1;
my ($nodesPattern) = @ARGV;

# Invoke the command
my $cmd = "qstat -f";
my $output = `$cmd 2>&1`;
my $rc     = $? >> 8;
die "$cmd failed with rc=$rc: $output\n" if $rc;

# Parse the output
my $jobId = "";
my @lines = split /\n/, $output;
foreach my $line (@lines)
{
    # Parse Job Id
    if ($line =~ /^Job Id: (\S+)/)
    {
        $jobId = $1;
    }

    # Print out the jobid if the nodes expression matches the nodes pattern
    elsif ($line =~ /Resource_List.nodes = (.*)/)
    {
        my $nodesExpression = $1;
        print "$jobId\n" if $nodesExpression =~ /$nodesPattern/;
    }
}
1;
__END__

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head2 EXPORT

=head2 EXPORT_OK

=head1 SEE ALSO

Additional information can be found at http://www.adaptivecomputing.com/

=head1 AUTHOR

Adaptive Computing, Inc., E<lt>http://www.adaptivecomputing.com/E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2010-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.

=cut
