#!/usr/bin/perl
###############################################################################
#
#
# clear_nodelist.pl
#
# This script changes the setting in -l h_rt nodelist=XXXXX to
#   nodelist=unassigned for the job specified by $JOB_ID.  It
#   is expected that that script be called from the prolog.  The
#   purpose of this is to make the change to the job so that
#   job.query.sge.pl does not have to.  When a large number of
#   jobs are launched on a large SGE instance, this will reduce
#   the total time that job.query.sge.pl has to run (which is
#   a good thing).
#
#
#   Copyright (C) 2010-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.
#
###############################################################################

use strict;

my $DEBUG=0;

printf STDERR "Starting clear_nodelist.pl $ENV{\"SGE_ROOT\"}\n" if $DEBUG;

my $sgeroot=$ENV{"SGE_ROOT"};
my $arch=`$sgeroot/util/arch`;
chomp($arch);

my $path="$sgeroot/bin/$arch/";

my $jobid=$ENV{"JOB_ID"};
if (!defined($jobid)) {
	print STDERR "Error, unable to find SGE JOB_ID, exiting\n";
	exit(1);
}


QSTATF:
{
    my $cmd    = "$path/qstat -j $jobid";
    my $output = `$cmd 2>&1` || `sh -c "$cmd 2>&1"`;
    my $rc     = $? >> 8;

    if ($rc != 0) {
	print STDERR "Error, unable to execute $cmd, exiting\n";
	exit(1); 
    }

    my @lines = split /\n/, $output;
    foreach my $line (@lines)
    {
        chomp $line;
	if ($line =~ /hard resource_list:\s+(\S+)/)
        {
		my @newres;
		foreach my $res (split(/,/,$1))
                {
			if ($res =~ /nodelist=(\S+)/)
                        {
				if ($1 eq "unassigned")
				{
					print STDERR "Job $jobid already has nodelist set to unassigned, exiting\n";
					exit(1);
				}
				$res="nodelist=unassigned";
			}
			push @newres, $res;
		}
		my $str;
 		$str=join(',',@newres);
		$cmd="$path/qalter -l $str $jobid";
    		my $output = `$cmd 2>&1` || `sh -c "$cmd 2>&1"`;
         	my $rc = $? >> 8;
		if ($rc != 0) {
			print STDERR "Error, unable to execute $cmd, exiting\n";
			exit(1);
		}
		# We are done, don't bother parsing the rest
		exit(0);
	}
    }
}

1;
__END__

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head2 EXPORT

=head2 EXPORT_OK

=head1 SEE ALSO

Additional information can be found at http://www.adaptivecomputing.com/

=head1 AUTHOR

Adaptive Computing, Inc., E<lt>http://www.adaptivecomputing.com/E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2010-2016 by Adaptive Computing Enterprises, Inc. All Rights Reserved.

=cut
