CREATE DATABASE IF NOT EXISTS Moab;

CONNECT Moab;
 
CREATE TABLE  mcheckpoint (
  object_type varchar(64) NOT NULL,
  object_name varchar(64) NOT NULL,
  timestamp bigint(20) NOT NULL default '0',
  data mediumtext NOT NULL,
  PRIMARY KEY  (object_type, object_name)
);
 
CREATE TABLE Moab (
  Version FLOAT(6)
);
 
CREATE TABLE ObjectType (
  ID INTEGER,
  Name VARCHAR(64),
  PRIMARY KEY (ID)
);
 
CREATE TABLE EventType (
  ID INTEGER,
  Name VARCHAR(64),
  PRIMARY KEY (ID)
);
 
CREATE TABLE GeneralStats (
  ObjectType INTEGER,
  ObjectName VARCHAR(64),
  Time INTEGER UNSIGNED,
  StatDuration INTEGER,
  IterationCount INTEGER,
  IntervalStatCount INTEGER,
  IntervalStatDuration INTEGER,
  TotalJobCount INTEGER,
  JobsSubmitted INTEGER,
  JobsActive INTEGER,
  JobsEligible INTEGER,
  JobsIdle INTEGER,
  JobsCompletedByQOS INTEGER,
  JobsQueued INTEGER,
  JobsPreempted INTEGER,
  TotalJobAccuracy DOUBLE,
  TotalNodeLoad DOUBLE,
  TotalNodeMemory DOUBLE,
  TotalNodeCount INTEGER,
  TotalAllocatedNodeCount INTEGER,
  TotalActiveNodeCount INTEGER,
  TotalActiveProcCount INTEGER,
  TotalConfiguredProcCount INTEGER,
  TotalAvailableCapacity INTEGER,
  ProcSecondsDedicated DOUBLE,
  ProcSecondsExecuted DOUBLE,
  ProcSecondsRequested DOUBLE,
  ProcSecondsUtilized DOUBLE,
  ProcHoursPreempted DOUBLE,
  ProcHoursSubmitted DOUBLE,
  ProcHoursQueued DOUBLE,
  ProcHoursAvailable DOUBLE,
  ProcHoursDedicated DOUBLE,
  ProcHoursSuccessful DOUBLE,
  ProcHoursUtilized DOUBLE,
  DiskSecondsAvailable DOUBLE,
  DiskSecondsDedicated DOUBLE,
  DiskSecondsUtilized DOUBLE,
  DiskSecondsUtilizedInstant DOUBLE,
  MemSecondsAvailable DOUBLE,
  MemSecondsDedicated DOUBLE,
  MemSecondsUtilized DOUBLE,
  AvgBypass INTEGER,
  MaxBypass INTEGER,
  TotalBypass INTEGER,
  AvgXFactor DOUBLE,
  MaxXFactor DOUBLE,
  AvgQueueTime DOUBLE,
  MaxQueueTime INTEGER,
  TotalQueueTime INTEGER,
  TotalRequestedWalltime DOUBLE,
  TotalExecutionWalltime DOUBLE,
  MinEfficiency DOUBLE,
  MinEfficiencyDuration DOUBLE,
  StartedJobCount INTEGER,
  StartedJobsQueueTime INTEGER,
  StartedJobsProcCount INTEGER,
  StartedJobsXFactor DOUBLE,
  TotalNodeWeightedXFactor DOUBLE,
  TotalNodeWeightedJobAccuracy DOUBLE,
  QOSCredits DOUBLE,
  AppBacklog DOUBLE,
  AppLoad DOUBLE,
  AppResponseTime DOUBLE,
  AppThroughput DOUBLE,
  TotalXFactor DOUBLE,
  Other VARCHAR(256),
  PRIMARY KEY (ObjectType, ObjectName, Time),
  FOREIGN KEY (ObjectType) REFERENCES ObjectType (ID)
);
 
CREATE TABLE GenericMetrics (
  ObjectType INTEGER,
  ObjectName VARCHAR(64),
  GMetricName VARCHAR(64),
  Time INTEGER UNSIGNED,
  GMetricValue DOUBLE,
  PRIMARY KEY (ObjectType, ObjectName, GMetricName, Time),
  FOREIGN KEY (ObjectType, ObjectName, Time) references GeneralStats(ObjectType, ObjectName, Time)
);
 
CREATE TABLE NodeStats (
  NodeID VARCHAR(64),
  Time INTEGER UNSIGNED,
  NodeState Integer,
  IterationCount INTEGER,
  IntervalStatCount INTEGER,
  IntervalStatDuration INTEGER,
  InternalNodeCategory VARCHAR(64),
  ExternalNodeCategory VARCHAR(64),
  TotalQueueTime INTEGER UNSIGNED,
  TotalXFactor DOUBLE,
  ProcsAvailable INTEGER,
  ProcsConfigured INTEGER,
  ProcsDedicated INTEGER,
  MaxMemoryUsed INTEGER,
  MinMemoryUsed INTEGER,
  TotalMemoryUsed INTEGER,
  StartJC INTEGER,
  FailureJC INTEGER,
  AvgCPULoad DOUBLE,
  MaxCPULoad DOUBLE,
  MinCPULoad DOUBLE,
  Category INTEGER,
  RCategory INTEGER,
  Other VARCHAR(256),
  CPUClock INTEGER,
  CPUMaxClock INTEGER,
  CPUMinClock INTEGER,
  PRIMARY KEY (NodeID, Time)
);
 
CREATE TABLE NodeStatsGenericResources (
  NodeID VARCHAR(64),
  GResName VARCHAR(64),
  Time INTEGER UNSIGNED,
  GenericResourcesAvailable INTEGER,
  GenericResourcesConfigured INTEGER,
  GenericResourcesDedicated INTEGER,
  PRIMARY KEY (NodeID, GResName, Time),
  FOREIGN KEY (NodeID, Time) references NodeStats(NodeID, Time)
);
 
CREATE TABLE Events (
  ID INTEGER,
  ObjectType INTEGER,
  EventType INTEGER,
  EventTime INTEGER UNSIGNED,
  ObjectName VARCHAR(64),
  Name VARCHAR(64),
  Description TEXT,
  PRIMARY KEY (ID)
);

CREATE TABLE Nodes (
  ID VARCHAR(64),
  State VARCHAR(64),
  OperatingSystem VARCHAR(64),
  ConfiguredProcessors INTEGER UNSIGNED,
  AvailableProcessors INTEGER UNSIGNED,
  ConfiguredMemory INTEGER UNSIGNED,
  AvailableMemory INTEGER UNSIGNED,
  Architecture VARCHAR(64),
  AvailGres VARCHAR(1024),
  ConfigGres VARCHAR(1024),
  AvailClasses VARCHAR(1024),
  ConfigClasses VARCHAR(1024),
  ChargeRate DOUBLE,
  DynamicPriority DOUBLE,
  EnableProfiling INTEGER UNSIGNED,
  Features VARCHAR(1024),
  GMetric VARCHAR(1024),
  HopCount INTEGER UNSIGNED,
  HypervisorType VARCHAR(64),
  IsDeleted INTEGER UNSIGNED,
  IsDynamic INTEGER UNSIGNED,
  JobList VARCHAR(1024),
  LastUpdateTime INTEGER UNSIGNED,
  LoadAvg DOUBLE,
  MaxLoad DOUBLE,
  MaxJob INTEGER UNSIGNED,
  MaxJobPerUser INTEGER UNSIGNED,
  MaxProc INTEGER UNSIGNED,
  MaxProcPerUser INTEGER UNSIGNED,
  OldMessages VARCHAR(1024),
  NetworkAddress VARCHAR(64),
  NodeSubstate VARCHAR(64),
  Operations VARCHAR(1024),
  OSList VARCHAR(1024),
  Owner VARCHAR(64),
  ResOvercommitFactor VARCHAR(64),
  PartitionName VARCHAR(64),
  PowerIsEnabled INTEGER UNSIGNED,
  PowerPolicy VARCHAR(64),
  PowerSelectState VARCHAR(64),
  PowerState VARCHAR(64),
  Priority INTEGER UNSIGNED,
  PriorityFunction VARCHAR(64),
  ProcessorSpeed INTEGER UNSIGNED,
  ProvisioningData VARCHAR(1024),
  AvailableDisk INTEGER UNSIGNED,  
  AvailableSwap INTEGER UNSIGNED,  
  ConfiguredDisk INTEGER UNSIGNED,
  ConfiguredSwap INTEGER UNSIGNED,
  ReservationCount INTEGER UNSIGNED,
  ReservationList VARCHAR(1024),
  ResourceManagerList VARCHAR(1024),
  SlotsUsed INTEGER UNSIGNED,
  Speed DOUBLE,
  SpeedWeight DOUBLE,
  TotalNodeActiveTime INTEGER UNSIGNED,
  LastModifyTime INTEGER UNSIGNED,
  TotalTimeTracked INTEGER UNSIGNED,
  TotalNodeUpTime INTEGER UNSIGNED,
  TaskCount INTEGER UNSIGNED,
  VMOSList VARCHAR(1024),
  CPUClock VARCHAR(64),
  PRIMARY KEY (ID)
);

CREATE TABLE Jobs (
  ID VARCHAR(64),
  SourceRMJobID VARCHAR(64),
  DestinationRMJobID VARCHAR(64),
  GridJobID VARCHAR(64),
  AName VARCHAR(64),
  UserName VARCHAR(64),
  Account VARCHAR(64),
  Class VARCHAR(64),
  QOS VARCHAR(64),
  OwnerGroup VARCHAR(64),
  JobGroup VARCHAR(64),
  State VARCHAR(64),
  EState VARCHAR(64),
  SubState VARCHAR(64),
  UserPriority INTEGER SIGNED,
  SystemPriority INTEGER SIGNED,
  CurrentStartPriority INTEGER SIGNED,
  RunPriority INTEGER SIGNED,
  PerPartitionPriority TEXT,
  SubmitTime INTEGER UNSIGNED, 
  QueueTime INTEGER UNSIGNED,
  StartTime INTEGER UNSIGNED,
  CompletionTime INTEGER UNSIGNED,
  CompletionCode INTEGER,
  UsedWalltime INTEGER UNSIGNED,
  RequestedMinWalltime INTEGER UNSIGNED,
  RequestedMaxWalltime INTEGER UNSIGNED,
  CPULimit INTEGER UNSIGNED,
  SuspendTime INTEGER UNSIGNED,
  HoldTime INTEGER UNSIGNED,
  ProcessorCount INTEGER,
  RequestedNodes INTEGER,
  ActivePartition VARCHAR(64),
  SpecPAL VARCHAR(64),
  DestinationRM VARCHAR(64),
  SourceRM VARCHAR(64),
  Flags TEXT,
  MinPreemptTime INTEGER UNSIGNED,
  Dependencies TEXT,
  RequestedHostList TEXT,
  ExcludedHostList TEXT,
  MasterHostName VARCHAR(64),
  GenericAttributes TEXT,
  Holds TEXT,
  Cost DOUBLE,
  Description TEXT,
  Messages TEXT,
  NotificationAddress TEXT,
  StartCount INTEGER UNSIGNED,
  BypassCount INTEGER UNSIGNED,
  CommandFile TEXT,
  Arguments TEXT,
  RMSubmitLanguage TEXT,
  StdIn TEXT,
  StdOut TEXT,
  StdErr TEXT,
  RMOutput TEXT,
  RMError TEXT,
  InitialWorkingDirectory TEXT,
  UMask INTEGER UNSIGNED,
  RsvStartTime INTEGER UNSIGNED,
  BlockReason TEXT,
  BlockMsg TEXT,
  PSDedicated DOUBLE,
  PSUtilized DOUBLE,
  Internal_ID BIGINT(32) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (Internal_ID)
);

CREATE TABLE JobHistory (
  ID VARCHAR(64),
  SourceRMJobID VARCHAR(64),
  DestinationRMJobID VARCHAR(64),
  GridJobID VARCHAR(64),
  AName VARCHAR(64),
  UserName VARCHAR(64),
  Account VARCHAR(64),
  Class VARCHAR(64),
  QOS VARCHAR(64),
  OwnerGroup VARCHAR(64),
  JobGroup VARCHAR(64),
  State VARCHAR(64),
  EState VARCHAR(64),
  SubState VARCHAR(64),
  UserPriority INTEGER UNSIGNED,
  SystemPriority INTEGER UNSIGNED,
  CurrentStartPriority INTEGER UNSIGNED,
  RunPriority INTEGER UNSIGNED,
  PerPartitionPriority TEXT,
  SubmitTime INTEGER UNSIGNED, 
  QueueTime INTEGER UNSIGNED,
  StartTime INTEGER UNSIGNED,
  CompletionTime INTEGER UNSIGNED,
  CompletionCode INTEGER,
  UsedWalltime INTEGER UNSIGNED,
  RequestedMinWalltime INTEGER UNSIGNED,
  RequestedMaxWalltime INTEGER UNSIGNED,
  CPULimit INTEGER UNSIGNED,
  SuspendTime INTEGER UNSIGNED,
  HoldTime INTEGER UNSIGNED,
  ProcessorCount INTEGER,
  RequestedNodes INTEGER,
  ActivePartition VARCHAR(64),
  SpecPAL VARCHAR(64),
  DestinationRM VARCHAR(64),
  SourceRM VARCHAR(64),
  Flags TEXT,
  MinPreemptTime INTEGER UNSIGNED,
  Dependencies TEXT,
  RequestedHostList TEXT,
  ExcludedHostList TEXT,
  MasterHostName VARCHAR(64),
  GenericAttributes TEXT,
  Holds TEXT,
  Cost DOUBLE,
  Description TEXT,
  Messages TEXT,
  NotificationAddress TEXT,
  StartCount INTEGER UNSIGNED,
  BypassCount INTEGER UNSIGNED,
  CommandFile TEXT,
  Arguments TEXT,
  RMSubmitLanguage TEXT,
  StdIn TEXT,
  StdOut TEXT,
  StdErr TEXT,
  RMOutput TEXT,
  RMError TEXT,
  InitialWorkingDirectory TEXT,
  UMask INTEGER UNSIGNED,
  RsvStartTime INTEGER UNSIGNED,
  BlockReason TEXT,
  BlockMsg TEXT,
  PSDedicated DOUBLE,
  PSUtilized DOUBLE,
  PRIMARY KEY (ID,SubmitTime)
);

CREATE TABLE Reservations (
  Name VARCHAR(64),
  ACL TEXT,
  AAccount VARCHAR(64),
  AGroup VARCHAR(64),
  AUser VARCHAR(64),
  AQOS VARCHAR(64),
  AllocNodeCount INTEGER UNSIGNED,
  AllocNodeList VARCHAR(1024),
  AllocProcCount INTEGER UNSIGNED,
  AllocTaskCount INTEGER UNSIGNED,
  CL TEXT,
  ReservationComment TEXT,
  Cost DOUBLE,
  CTime INTEGER UNSIGNED,
  Duration INTEGER UNSIGNED,
  EndTime INTEGER UNSIGNED,
  ExcludeRsv TEXT,
  ExpireTime INTEGER UNSIGNED,
  Flags TEXT,
  GlobalID TEXT,
  HostExp TEXT,
  History TEXT,
  Label TEXT,
  LastChargeTime INTEGER UNSIGNED,
  LogLevel VARCHAR(64),
  Messages TEXT,
  Owner VARCHAR(64),
  PartitionName VARCHAR(64),
  Profile VARCHAR(64),
  ReqArch VARCHAR(64),
  ReqFeatureList TEXT,
  ReqMemory VARCHAR(64),
  ReqNodeCount VARCHAR(64),
  ReqNodeList TEXT,
  ReqOS VARCHAR(64),
  ReqTaskCount VARCHAR(64),
  ReqTPN  VARCHAR(64),
  Resources VARCHAR(64),
  RsvAccessList TEXT,
  RsvGroup VARCHAR(64),
  RsvParent VARCHAR(64),
  SID VARCHAR(64),
  StartTime INTEGER UNSIGNED,
  StatCBPS INTEGER,
  StatCRPS INTEGER,
  StatTBPS INTEGER,
  StatTRPS INTEGER,
  SubType VARCHAR(64),
  TTrigger VARCHAR(64),
  TType VARCHAR(64),
  Variables VARCHAR(1024),
  VMList TEXT,
  PRIMARY KEY (NAME)
);

CREATE TABLE Triggers (
  TrigID VARCHAR(64),
  Name VARCHAR(64),
  ActionData VARCHAR(1024),
  ActionType VARCHAR(64),
  BlockTime INTEGER UNSIGNED,
  Description VARCHAR(1024),
  Disabled INTEGER UNSIGNED,
  EBuf VARCHAR(1024),
  EventTime INTEGER UNSIGNED,
  EventType VARCHAR(64),
  FailOffset VARCHAR(64),
  FailureDetected INTEGER UNSIGNED,
  Flags VARCHAR(1024),
  IsComplete INTEGER UNSIGNED,
  IsInterval INTEGER UNSIGNED,
  LaunchTime INTEGER UNSIGNED,
  Message VARCHAR(1024),
  MultiFire VARCHAR(64),
  ObjectID VARCHAR(64),
  ObjectType VARCHAR(64),
  OBuf VARCHAR(1024),
  TriggerOffset VARCHAR(64),
  Period VARCHAR(64),
  PID INTEGER UNSIGNED,
  RearmTime INTEGER UNSIGNED,
  Requires VARCHAR(1024),
  Sets VARCHAR(1024),
  State VARCHAR(64),
  Threshold VARCHAR(64),
  Timeout INTEGER UNSIGNED,
  Unsets VARCHAR(1024),
  PRIMARY KEY (TrigID)
);

CREATE TABLE VCs (
  Name VARCHAR(64),
  Description VARCHAR(1024),
  Jobs TEXT,
  Nodes TEXT,
  VMs TEXT,
  Rsvs TEXT,
  VCs TEXT,
  Variables TEXT,
  Flags TEXT,
  PRIMARY KEY (NAME)
);

CREATE TABLE Requests (
  JobID VARCHAR(64),
  RIndex INTEGER UNSIGNED,
  AllocNodeList VARCHAR(1024),
  AllocPartition VARCHAR(64),
  PartitionIndex INTEGER UNSIGNED,
  NodeAccessPolicy VARCHAR(64),
  PreferredFeatures TEXT,
  RequestedApp VARCHAR(64),
  RequestedArch VARCHAR(64),
  ReqOS VARCHAR(64),
  ReqNodeSet VARCHAR(64),
  ReqPartition VARCHAR(64),
  MinNodeCount INTEGER UNSIGNED,
  MinTaskCount INTEGER UNSIGNED,
  TaskCount INTEGER UNSIGNED,
  TasksPerNode INTEGER UNSIGNED,
  DiskPerTask INTEGER UNSIGNED,
  MemPerTask INTEGER UNSIGNED,
  ProcsPerTask INTEGER UNSIGNED,
  SwapPerTask INTEGER UNSIGNED,
  NodeDisk VARCHAR(64),
  NodeFeatures TEXT,
  NodeMemory VARCHAR(64),
  NodeSwap VARCHAR(64),
  NodeProcs VARCHAR(64),
  GenericResources TEXT,
  ConfiguredGenericResources TEXT,
  CPUClock VARCHAR(64),
  PRIMARY KEY (JobID,RIndex)
);
 
CREATE INDEX EVENTS_NAME on Events (Name);
CREATE INDEX EVENTS_TIME on Events (EventTime);
CREATE INDEX EVENTS_ETYPE on Events (EventType);
CREATE INDEX EVENTS_OTYPE on Events (ObjectType);
CREATE INDEX EVENTS_ONAME on Events (ObjectName);
CREATE INDEX EVENTTYPE_NAME on EventType(Name);
CREATE INDEX OBJECTTYPE_NAME on ObjectType(Name);
 
INSERT INTO ObjectType (Name,ID) VALUES ("Acct",1);
INSERT INTO ObjectType (Name,ID) VALUES ("AM",2);
INSERT INTO ObjectType (Name,ID) VALUES ("Class",3);
INSERT INTO ObjectType (Name,ID) VALUES ("Cluster",4);
INSERT INTO ObjectType (Name,ID) VALUES ("Group",5);
INSERT INTO ObjectType (Name,ID) VALUES ("Job",6);
INSERT INTO ObjectType (Name,ID) VALUES ("Node",7);
INSERT INTO ObjectType (Name,ID) VALUES ("Par",8);
INSERT INTO ObjectType (Name,ID) VALUES ("QOS",9);
INSERT INTO ObjectType (Name,ID) VALUES ("Rsv",13);
INSERT INTO ObjectType (Name,ID) VALUES ("RM",14);
INSERT INTO ObjectType (Name,ID) VALUES ("Sched",15);
INSERT INTO ObjectType (Name,ID) VALUES ("SRsv",16);
INSERT INTO ObjectType (Name,ID) VALUES ("Sys",17);
INSERT INTO ObjectType (Name,ID) VALUES ("TNode",18);
INSERT INTO ObjectType (Name,ID) VALUES ("Trig",19);
INSERT INTO ObjectType (Name,ID) VALUES ("User",20);
INSERT INTO ObjectType (Name,ID) VALUES ("ID",21);
INSERT INTO ObjectType (Name,ID) VALUES ("CJob",23);
INSERT INTO ObjectType (Name,ID) VALUES ("GRes",30);
INSERT INTO ObjectType (Name,ID) VALUES ("Gmetric",31);
INSERT INTO ObjectType (Name,ID) VALUES ("Stats",39);
INSERT INTO ObjectType (Name,ID) VALUES ("TJob",42);
INSERT INTO ObjectType (Name,ID) VALUES ("Paction",43);
INSERT INTO ObjectType (Name,ID) VALUES ("VM",45);
INSERT INTO ObjectType (Name,ID) VALUES ("VPC",47);
INSERT INTO ObjectType (Name,ID) VALUES ("JGroup",48);

INSERT INTO EventType (Name,ID) VALUES ("[NONE]",0);
INSERT INTO EventType (Name,ID) VALUES ("GEVENT",1);
INSERT INTO EventType (Name,ID) VALUES ("JOBCANCEL",2);
INSERT INTO EventType (Name,ID) VALUES ("JOBEND",3);
INSERT INTO EventType (Name,ID) VALUES ("JOBFAILURE",4);
INSERT INTO EventType (Name,ID) VALUES ("JOBHOLD",5);
INSERT INTO EventType (Name,ID) VALUES ("JOBMIGRATE",6);
INSERT INTO EventType (Name,ID) VALUES ("JOBMODIFY",7);
INSERT INTO EventType (Name,ID) VALUES ("JOBPREEMPT",8);
INSERT INTO EventType (Name,ID) VALUES ("JOBREJECT",9);
INSERT INTO EventType (Name,ID) VALUES ("JOBRESUME",10);
INSERT INTO EventType (Name,ID) VALUES ("JOBSTART",11);
INSERT INTO EventType (Name,ID) VALUES ("JOBSUBMIT",12);
INSERT INTO EventType (Name,ID) VALUES ("JOBUPDATE",13);
INSERT INTO EventType (Name,ID) VALUES ("JOBVARSET",14);
INSERT INTO EventType (Name,ID) VALUES ("JOBVARUNSET",15);
INSERT INTO EventType (Name,ID) VALUES ("NODEDOWN",16);
INSERT INTO EventType (Name,ID) VALUES ("NODEFAILURE",17);
INSERT INTO EventType (Name,ID) VALUES ("NODEUP",18);
INSERT INTO EventType (Name,ID) VALUES ("NODEUPDATE",19);
INSERT INTO EventType (Name,ID) VALUES ("NOTE",20);
INSERT INTO EventType (Name,ID) VALUES ("QOSVIOLATION",21);
INSERT INTO EventType (Name,ID) VALUES ("RMDOWN",22);
INSERT INTO EventType (Name,ID) VALUES ("RMUP",23);
INSERT INTO EventType (Name,ID) VALUES ("RSVCANCEL",24);
INSERT INTO EventType (Name,ID) VALUES ("RSVCREATE",25);
INSERT INTO EventType (Name,ID) VALUES ("RSVEND",26);
INSERT INTO EventType (Name,ID) VALUES ("RSVMODIFY",27);
INSERT INTO EventType (Name,ID) VALUES ("RSVSTART",28);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDCOMMAND",29);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDFAILURE",30);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDMODIFY",31);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDPAUSE",32);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDRECYCLE",33);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDRESUME",34);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDSTART",35);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDSTOP",36);
INSERT INTO EventType (Name,ID) VALUES ("TRIGCREATE",37);
INSERT INTO EventType (Name,ID) VALUES ("TRIGEND",38);
INSERT INTO EventType (Name,ID) VALUES ("TRIGFAILURE",39);
INSERT INTO EventType (Name,ID) VALUES ("TRIGSTART",40);
INSERT INTO EventType (Name,ID) VALUES ("TRIGTHRESHOLD",41);
INSERT INTO EventType (Name,ID) VALUES ("VMCREATE",42);
INSERT INTO EventType (Name,ID) VALUES ("VMDESTROY",43);
INSERT INTO EventType (Name,ID) VALUES ("VMMIGRATE",44);
INSERT INTO EventType (Name,ID) VALUES ("VMPOWERON",45);
INSERT INTO EventType (Name,ID) VALUES ("VMPOWEROFF",46);
INSERT INTO EventType (Name,ID) VALUES ("NODEMODIFY",47);
INSERT INTO EventType (Name,ID) VALUES ("NODEPOWEROFF",48);
INSERT INTO EventType (Name,ID) VALUES ("NODEPOWERON",49);
INSERT INTO EventType (Name,ID) VALUES ("NODEPROVISION",50);
INSERT INTO EventType (Name,ID) VALUES ("ALLSCHEDCOMMAND",51);
INSERT INTO EventType (Name,ID) VALUES ("AMDELETE",52);
INSERT INTO EventType (Name,ID) VALUES ("AMEND",53);
INSERT INTO EventType (Name,ID) VALUES ("AMQUOTE",54);
INSERT INTO EventType (Name,ID) VALUES ("AMSTART",55);
INSERT INTO EventType (Name,ID) VALUES ("RMPOLLEND",56);
INSERT INTO EventType (Name,ID) VALUES ("RMPOLLSTART",57);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDCYCLEEND",58);
INSERT INTO EventType (Name,ID) VALUES ("SCHEDCYCLESTART",59);
INSERT INTO EventType (Name,ID) VALUES ("JOBCHECKPOINT",60);
INSERT INTO EventType (Name,ID) VALUES ("AMCREATE",61);
INSERT INTO EventType (Name,ID) VALUES ("AMUPDATE",62);
INSERT INTO EventType (Name,ID) VALUES ("AMPAUSE",63);
INSERT INTO EventType (Name,ID) VALUES ("AMRESUME",64);
INSERT INTO EventType (Name,ID) VALUES ("AMMODIFY",65);
INSERT INTO EventType (Name,ID) VALUES ("AMCONTINUE",66);
INSERT INTO EventType (Name,ID) VALUES ("NODEREMOVE",67);
INSERT INTO EventType (Name,ID) VALUES ("NODEADD",68);

DELIMITER //
CREATE TRIGGER job_history_trig BEFORE INSERT ON Jobs
  FOR EACH ROW BEGIN
    IF NEW.CompletionTime > 0 THEN
      INSERT INTO JobHistory (
        ID, 
        SourceRMJobID,
        DestinationRMJobID,
        GridJobID,
        AName,
        UserName,
        Account,
        Class,
        QOS,
        OwnerGroup,
        JobGroup,
        State,
        EState,
        SubState,
        UserPriority,
        SystemPriority,
        CurrentStartPriority,
        RunPriority,
        PerPartitionPriority,
        SubmitTime,
        QueueTime,
        StartTime,
        CompletionTime,
        CompletionCode,
        UsedWalltime,
        RequestedMinWalltime,
        RequestedMaxWalltime,
        CPULimit,
        SuspendTime,
        HoldTime,
        ProcessorCount,
        RequestedNodes,
        ActivePartition,
        SpecPAL,
        DestinationRM,
        SourceRM,
        Flags,
        MinPreemptTime,
        Dependencies,
        RequestedHostList,
        ExcludedHostList,
        MasterHostName,
        GenericAttributes,
        Holds,
        Cost,
        Description,
        Messages,
        NotificationAddress,
        StartCount,
        BypassCount,
        CommandFile,
        Arguments,
        RMSubmitLanguage,
        StdIn,
        StdOut,
        StdErr,
        RMOutput,
        RMError,
        InitialWorkingDirectory,
        UMask,
        RsvStartTime,
        BlockReason,
        BlockMsg,
        PSDedicated,
        PSUtilized)
      VALUES (
        NEW.ID,
        NEW.SourceRMJobID,
        NEW.DestinationRMJobID,
        NEW.GridJobID,
        NEW.AName,
        NEW.UserName,
        NEW.Account,
        NEW.Class,
        NEW.QOS,
        NEW.OwnerGroup,
        NEW.JobGroup,
        NEW.State,
        NEW.EState,
        NEW.SubState,
        NEW.UserPriority,
        NEW.SystemPriority,
        NEW.CurrentStartPriority,
        NEW.RunPriority,
        NEW.PerPartitionPriority,
        NEW.SubmitTime,
        NEW.QueueTime,
        NEW.StartTime,
        NEW.CompletionTime,
        NEW.CompletionCode,
        NEW.UsedWalltime,
        NEW.RequestedMinWalltime,
        NEW.RequestedMaxWalltime,
        NEW.CPULimit,
        NEW.SuspendTime,
        NEW.HoldTime,
        NEW.ProcessorCount,
        NEW.RequestedNodes,
        NEW.ActivePartition,
        NEW.SpecPAL,
        NEW.DestinationRM,
        NEW.SourceRM,
        NEW.Flags,
        NEW.MinPreemptTime,
        NEW.Dependencies,
        NEW.RequestedHostList,
        NEW.ExcludedHostList,
        NEW.MasterHostName,
        NEW.GenericAttributes,
        NEW.Holds,
        NEW.Cost,
        NEW.Description,
        NEW.Messages,
        NEW.NotificationAddress,
        NEW.StartCount,
        NEW.BypassCount,
        NEW.CommandFile,
        NEW.Arguments,
        NEW.RMSubmitLanguage,
        NEW.StdIn,
        NEW.StdOut,
        NEW.StdErr,
        NEW.RMOutput,
        NEW.RMError,
        NEW.InitialWorkingDirectory,
        NEW.UMask,
        NEW.RsvStartTime,
        NEW.BlockReason,
        NEW.BlockMsg,
        NEW.PSDedicated,
        NEW.PSUtilized);
    END IF;
  END;//
DELIMITER ;
