-- This MySQL script alters Moab 7.0 tables to the current Moab version for all Moab suites and
-- may add additional definition information.
--   Moab HPC Suite - Basic Edition
--   Moab HPC Suite - Enterprise Edition
--   Moab Cloud Suite
--
-- The script is organized into three sections.
--   Deletions
--   Alterations
--   Additions
-- ====================================================================================================
-- MySQL DBA: Assign the "Moab" user name the additional "RESOURCE" and "DBA" permissions.  Log in
-- with the Moab user name and execute the following DDL statements to update the Moab database from
-- the version contained in this script's file name to the current version, then remove the "DBA" and
-- "RESOURCE" permissions from the "Moab" user name to prevent inadvertant alteration of the "Moab"
-- schema.
--
-- This script is for your convenience in updating the Moab database to the current Moab version.
--
-- If you have added your own custom indexes and/or foreign key definitions to the Moab database for
-- performance purposes for your own use cases, check the DDL and DML statements below to verify they
-- will not interfere with your custom alterations.  If they will, adjust the statements below or add
-- DDL statements for your own alterations to accommodate the Moab modifications below.
--
-- You cannot remove new column or table definitions since the Moab product will require them!
--
-- If you want to retain deleted obsolete columns or tables, be aware you are responsible to maintain
-- them from this point on since the Moab product will not be aware of their presence!

CONNECT Moab;

-- ===================================
-- Drop obsolete Moab procedures/triggers
-- ===================================


-- ==================================
-- Drop obsolete Moab table indexes
-- ==================================


-- ===========================
-- Drop obsolete Moab tables
-- ===========================


-- =============================================
-- Delete obsolete pre-defined Moab definitions
-- =============================================


-- =================================================================
-- Alter existing Moab tables to match current version definitions
-- =================================================================
ALTER TABLE Jobs CHANGE COLUMN User UserName VARCHAR(64);
ALTER TABLE Jobs MODIFY COLUMN UserPriority INTEGER SIGNED;
ALTER TABLE Jobs MODIFY COLUMN SystemPriority INTEGER SIGNED;
ALTER TABLE Jobs MODIFY COLUMN CurrentStartPriority INTEGER SIGNED;
ALTER TABLE Jobs MODIFY COLUMN RunPriority INTEGER SIGNED;

ALTER TABLE Triggers CHANGE COLUMN Offset TriggerOffset VARCHAR(64);

-- ========================
-- Create new Moab tables
-- ========================
CREATE TABLE JobHistory (
  ID VARCHAR(64),
  SourceRMJobID VARCHAR(64),
  DestinationRMJobID VARCHAR(64),
  GridJobID VARCHAR(64),
  AName VARCHAR(64),
  UserName VARCHAR(64),
  Account VARCHAR(64),
  Class VARCHAR(64),
  QOS VARCHAR(64),
  OwnerGroup VARCHAR(64),
  JobGroup VARCHAR(64),
  State VARCHAR(64),
  EState VARCHAR(64),
  SubState VARCHAR(64),
  UserPriority INTEGER UNSIGNED,
  SystemPriority INTEGER UNSIGNED,
  CurrentStartPriority INTEGER UNSIGNED,
  RunPriority INTEGER UNSIGNED,
  PerPartitionPriority TEXT,
  SubmitTime INTEGER UNSIGNED, 
  QueueTime INTEGER UNSIGNED,
  StartTime INTEGER UNSIGNED,
  CompletionTime INTEGER UNSIGNED,
  CompletionCode INTEGER,
  UsedWalltime INTEGER UNSIGNED,
  RequestedMinWalltime INTEGER UNSIGNED,
  RequestedMaxWalltime INTEGER UNSIGNED,
  CPULimit INTEGER UNSIGNED,
  SuspendTime INTEGER UNSIGNED,
  HoldTime INTEGER UNSIGNED,
  ProcessorCount INTEGER,
  RequestedNodes INTEGER,
  ActivePartition VARCHAR(64),
  SpecPAL VARCHAR(64),
  DestinationRM VARCHAR(64),
  SourceRM VARCHAR(64),
  Flags TEXT,
  MinPreemptTime INTEGER UNSIGNED,
  Dependencies TEXT,
  RequestedHostList TEXT,
  ExcludedHostList TEXT,
  MasterHostName VARCHAR(64),
  GenericAttributes TEXT,
  Holds TEXT,
  Cost DOUBLE,
  Description TEXT,
  Messages TEXT,
  NotificationAddress TEXT,
  StartCount INTEGER UNSIGNED,
  BypassCount INTEGER UNSIGNED,
  CommandFile TEXT,
  Arguments TEXT,
  RMSubmitLanguage TEXT,
  StdIn TEXT,
  StdOut TEXT,
  StdErr TEXT,
  RMOutput TEXT,
  RMError TEXT,
  InitialWorkingDirectory TEXT,
  UMask INTEGER UNSIGNED,
  RsvStartTime INTEGER UNSIGNED,
  BlockReason TEXT,
  BlockMsg TEXT,
  PSDedicated DOUBLE,
  PSUtilized DOUBLE,
  PRIMARY KEY (ID,SubmitTime)
);

-- =================================================
-- Add new original Moab triggers/stored procedures
-- =================================================

DELIMITER //
CREATE TRIGGER job_history_trig BEFORE INSERT ON Jobs
  FOR EACH ROW BEGIN
    IF NEW.CompletionTime > 0 THEN
      INSERT INTO JobHistory (
        ID, 
        SourceRMJobID,
        DestinationRMJobID,
        GridJobID,
        AName,
        UserName,
        Account,
        Class,
        QOS,
        OwnerGroup,
        JobGroup,
        State,
        EState,
        SubState,
        UserPriority,
        SystemPriority,
        CurrentStartPriority,
        RunPriority,
        PerPartitionPriority,
        SubmitTime,
        QueueTime,
        StartTime,
        CompletionTime,
        CompletionCode,
        UsedWalltime,
        RequestedMinWalltime,
        RequestedMaxWalltime,
        CPULimit,
        SuspendTime,
        HoldTime,
        ProcessorCount,
        RequestedNodes,
        ActivePartition,
        SpecPAL,
        DestinationRM,
        SourceRM,
        Flags,
        MinPreemptTime,
        Dependencies,
        RequestedHostList,
        ExcludedHostList,
        MasterHostName,
        GenericAttributes,
        Holds,
        Cost,
        Description,
        Messages,
        NotificationAddress,
        StartCount,
        BypassCount,
        CommandFile,
        Arguments,
        RMSubmitLanguage,
        StdIn,
        StdOut,
        StdErr,
        RMOutput,
        RMError,
        InitialWorkingDirectory,
        UMask,
        RsvStartTime,
        BlockReason,
        BlockMsg,
        PSDedicated,
        PSUtilized)
      VALUES (
        NEW.ID,
        NEW.SourceRMJobID,
        NEW.DestinationRMJobID,
        NEW.GridJobID,
        NEW.AName,
        NEW.UserName,
        NEW.Account,
        NEW.Class,
        NEW.QOS,
        NEW.OwnerGroup,
        NEW.JobGroup,
        NEW.State,
        NEW.EState,
        NEW.SubState,
        NEW.UserPriority,
        NEW.SystemPriority,
        NEW.CurrentStartPriority,
        NEW.RunPriority,
        NEW.PerPartitionPriority,
        NEW.SubmitTime,
        NEW.QueueTime,
        NEW.StartTime,
        NEW.CompletionTime,
        NEW.CompletionCode,
        NEW.UsedWalltime,
        NEW.RequestedMinWalltime,
        NEW.RequestedMaxWalltime,
        NEW.CPULimit,
        NEW.SuspendTime,
        NEW.HoldTime,
        NEW.ProcessorCount,
        NEW.RequestedNodes,
        NEW.ActivePartition,
        NEW.SpecPAL,
        NEW.DestinationRM,
        NEW.SourceRM,
        NEW.Flags,
        NEW.MinPreemptTime,
        NEW.Dependencies,
        NEW.RequestedHostList,
        NEW.ExcludedHostList,
        NEW.MasterHostName,
        NEW.GenericAttributes,
        NEW.Holds,
        NEW.Cost,
        NEW.Description,
        NEW.Messages,
        NEW.NotificationAddress,
        NEW.StartCount,
        NEW.BypassCount,
        NEW.CommandFile,
        NEW.Arguments,
        NEW.RMSubmitLanguage,
        NEW.StdIn,
        NEW.StdOut,
        NEW.StdErr,
        NEW.RMOutput,
        NEW.RMError,
        NEW.InitialWorkingDirectory,
        NEW.UMask,
        NEW.RsvStartTime,
        NEW.BlockReason,
        NEW.BlockMsg,
        NEW.PSDedicated,
        NEW.PSUtilized);
    END IF;
  END;//
DELIMITER ;
