-- This MySQL script alters Moab 7.2 tables to the current Moab version for all Moab suites and
-- may add additional definition information.
--   Moab HPC Suite - Basic Edition
--   Moab HPC Suite - Enterprise Edition
--   Moab Cloud Suite
--
-- The script is organized into three sections.
--   Deletions
--   Alterations
--   Additions
-- ====================================================================================================
-- MySQL DBA: Assign the "Moab" user name the additional "RESOURCE" and "DBA" permissions.  Log in
-- with the Moab user name and execute the following DDL statements to update the Moab database from
-- the version contained in this script's file name to the current version, then remove the "DBA" and
-- "RESOURCE" permissions from the "Moab" user name to prevent inadvertant alteration of the "Moab"
-- schema.
--
-- This script is for your convenience in updating the Moab database to the current Moab version.
--
-- If you have added your own custom indexes and/or foreign key definitions to the Moab database for
-- performance purposes for your own use cases, check the DDL and DML statements below to verify they
-- will not interfere with your custom alterations.  If they will, adjust the statements below or add
-- DDL statements for your own alterations to accommodate the Moab modifications below.
--
-- You cannot remove new column or table definitions since the Moab product will require them!
--
-- If you want to retain deleted obsolete columns or tables, be aware you are responsible to maintain
-- them from this point on since the Moab product will not be aware of their presence!


-- ===================================
-- Drop obsolete Moab procedures/triggers
-- ===================================


-- ==================================
-- Drop obsolete Moab table indexes
-- ==================================


-- ===========================
-- Drop obsolete Moab tables
-- ===========================


-- =============================================
-- Delete obsolete pre-defined Moab definitions
-- =============================================


-- =================================================================
-- Alter existing Moab tables to match current version definitions
-- =================================================================
-- Begin changes as of 7.2.6
ALTER TABLE Nodes MODIFY AvailGres           VARCHAR(1024);
ALTER TABLE Nodes MODIFY ConfigGres          VARCHAR(1024);
ALTER TABLE Nodes MODIFY AvailClasses        VARCHAR(1024);
ALTER TABLE Nodes MODIFY ConfigClasses       VARCHAR(1024);
ALTER TABLE Nodes MODIFY Features            VARCHAR(1024);
ALTER TABLE Nodes MODIFY GMetric             VARCHAR(1024);
ALTER TABLE Nodes MODIFY JobList             VARCHAR(1024);
ALTER TABLE Nodes MODIFY OldMessages         VARCHAR(1024);
ALTER TABLE Nodes MODIFY Operations          VARCHAR(1024);
ALTER TABLE Nodes MODIFY OSList              VARCHAR(1024);
ALTER TABLE Nodes MODIFY ProvisioningData    VARCHAR(1024);
ALTER TABLE Nodes MODIFY ReservationList     VARCHAR(1024);
ALTER TABLE Nodes MODIFY ResourceManagerList VARCHAR(1024);
ALTER TABLE Nodes MODIFY VMOSList            VARCHAR(1024);

ALTER TABLE Triggers MODIFY ActionData       VARCHAR(1024);
ALTER TABLE Triggers MODIFY Description      VARCHAR(1024);
ALTER TABLE Triggers MODIFY EBuf             VARCHAR(1024);
ALTER TABLE Triggers MODIFY Flags            VARCHAR(1024);
ALTER TABLE Triggers MODIFY Message          VARCHAR(1024);
ALTER TABLE Triggers MODIFY OBuf             VARCHAR(1024);
ALTER TABLE Triggers MODIFY Requires         VARCHAR(1024);
ALTER TABLE Triggers MODIFY Sets             VARCHAR(1024);
ALTER TABLE Triggers MODIFY Unsets           VARCHAR(1024);

-- Remove Trigger Name from Primary Key. The primary key should only be TrigID.
ALTER TABLE Triggers drop primary key, add primary key (TrigID);

ALTER TABLE VCs MODIFY Description           VARCHAR(1024);
-- End changes as of 7.2.6


-- ========================
-- Create new Moab tables
-- ========================


-- =================================================
-- Add new original Moab triggers/stored procedures
-- =================================================
