-- This Oracle SQL script drops Moab tables for all Moab suites.
--   Moab HPC Suite - Basic Edition
--   Moab HPC Suite - Enterprise Edition
--   Moab Cloud Suite
--
-- The script is organized into three sections.
--   Trigger/stored procedure deletions
--   Index deletions
--   Table deletions
--====================================================================================================
-- Oracle DBA: Assign the "Moab" user name the "CONNECT", "RESOURCE", and "DBA" permissions.  Log in
-- with the Moab user name and execute the following DDL statements to remove the Moab database, then
-- either remove the "Moab" user name/schema to completely remove the Moab database or remove the
-- "DBA" and "RESOURCE" permissions from the "Moab" user name to prevent inadvertant use of the "Moab"
-- user name and schema, which leaves a completely empty Moab database.
--
-- This script is for your convenience in deleting the Moab database.  After execution of this script,
-- you can use the Moab database creation script to create a new Moab database.
--
-- If you have particular business use cases for which you created additional indexes for performance
-- purposes, add index deletion DDL statements below in the appropriate place.  This should only be
-- for indexes to tables that hold PERSISTENT data between Moab restarts; that is, those tables that
-- contain historical information.  Those tables that represent Moab's "current state" should not have
-- any index definitions.
-- If you added additional trigger or stored procedure definitions, add their deletion DDL statements
-- below in the appropriate place.


-- Drop triggers/stored procedures in the reverse order in which they were created
--   Business use case triggers/stored procedures

--   Original Moab triggers/stored procedures
DROP TRIGGER job_history_trig;
DROP TRIGGER jobs_pk_incr;
DROP PROCEDURE insert_job_history;
DROP PROCEDURE update_job_history;

DROP SEQUENCE jobs_pk_seq;


-- Drop table indexes in the reverse order in which they were created
--   Business use case indexes

--   Original Moab indexes
DROP INDEX Events_OName_IX;
DROP INDEX Events_OType_IX;
DROP INDEX Events_EType_IX;
DROP INDEX Events_Time_IX;
DROP INDEX Events_Name_IX;
DROP INDEX ObjectType_Name_IX;
DROP INDEX EventType_Name_IX;


-- Drop tables and synonyms in the reverse order in which they were created
--   Business use case tables

--   Original Moab tables
DROP TABLE VCs;
DROP PUBLIC SYNONYM VCs;
DROP TABLE Triggers;
DROP PUBLIC SYNONYM Triggers;
DROP TABLE Reservations;
DROP PUBLIC SYNONYM Reservations;
DROP TABLE Requests;
DROP PUBLIC SYNONYM Requests;
DROP TABLE Jobs;
DROP PUBLIC SYNONYM Jobs;
DROP TABLE Nodes;
DROP PUBLIC SYNONYM Nodes;
DROP TABLE mcheckpoint;
DROP PUBLIC SYNONYM mcheckpoint;
DROP TABLE JobHistory;
DROP PUBLIC SYNONYM JobHistory;
DROP TABLE Events;
DROP PUBLIC SYNONYM Events;
DROP TABLE NodeStatsGenericResources;
DROP PUBLIC SYNONYM NodeStatsGenericResources;
DROP TABLE NodeStats;
DROP PUBLIC SYNONYM NodeStats;
DROP TABLE GenericMetrics;
DROP PUBLIC SYNONYM GenericMetrics;
DROP TABLE GeneralStats;
DROP PUBLIC SYNONYM GeneralStats;
DROP TABLE EventType;
DROP PUBLIC SYNONYM EventType;
DROP TABLE ObjectType;
DROP PUBLIC SYNONYM ObjectType;
DROP TABLE Moab;
DROP PUBLIC SYNONYM Moab;
