-- This Oracle SQL script alters Moab 7.2 tables to the current Moab version for all Moab suites and
-- may add additional definition information.
--   Moab HPC Suite - Basic Edition
--   Moab HPC Suite - Enterprise Edition
--   Moab Cloud Suite
--
-- The script is organized into three sections.
--   Deletions
--   Alterations
--   Additions
--====================================================================================================
-- Oracle SQL DBA: Assign the "Moab" user name the additional "RESOURCE" and "DBA" permissions.  Log in
-- with the Moab user name and execute the following DDL statements to update the Moab database from
-- the version contained in this script's file name to the current version, then remove the "DBA" and
-- "RESOURCE" permissions from the "Moab" user name to prevent inadvertant alteration of the "Moab"
-- schema.
--
-- This script is for your convenience in updating the Moab database to the current Moab version.
--
-- If you have added your own custom indexes and/or foreign key definitions to the Moab database for
-- performance purposes for your own use cases, check the DDL and DML statements below to verify they
-- will not interfere with your custom alterations.  If they will, adjust the statements below or add
-- DDL statements for your own alterations to accommodate the Moab modifications below.
--
-- You cannot remove new column or table definitions since the Moab product will require them!
--
-- If you want to retain deleted obsolete columns or tables, be aware you are responsible to maintain
-- them from this point on since the Moab product will not be aware of their presence!


--===================================
-- Drop obsolete Moab procedures/triggers
--===================================


--==================================
-- Drop obsolete Moab table indexes
--==================================


--===========================
-- Drop obsolete Moab tables
--===========================


--=============================================
-- Delete obsolete pre-defined Moab definitions
--=============================================


--=================================================================
-- Alter existing Moab tables to match current version definitions
--=================================================================
-- Begin changes as of 7.2.6
CREATE PUBLIC SYNONYM MOAB FOR MOAB.MOAB;
CREATE PUBLIC SYNONYM OBJECTTYPE FOR MOAB.OBJECTTYPE;
CREATE PUBLIC SYNONYM EVENTTYPE FOR MOAB.EVENTTYPE;
CREATE PUBLIC SYNONYM GENERALSTATS FOR MOAB.GENERALSTATS;
CREATE PUBLIC SYNONYM GENERICMETRICS FOR MOAB.GENERICMETRICS;
CREATE PUBLIC SYNONYM NODESTATS FOR MOAB.NODESTATS;
CREATE PUBLIC SYNONYM NODESTATSGENERICRESOURCES FOR MOAB.NODESTATSGENERICRESOURCES;
CREATE PUBLIC SYNONYM EVENTS FOR MOAB.EVENTS;
CREATE PUBLIC SYNONYM JOBHISTORY FOR MOAB.JOBHISTORY;
CREATE PUBLIC SYNONYM MCHECKPOINT FOR MOAB.MCHECKPOINT;
CREATE PUBLIC SYNONYM NODES FOR MOAB.NODES;
CREATE PUBLIC SYNONYM JOBS FOR MOAB.JOBS;
CREATE PUBLIC SYNONYM REQUESTS FOR MOAB.REQUESTS;
CREATE PUBLIC SYNONYM RESERVATIONS FOR MOAB.RESERVATIONS;
CREATE PUBLIC SYNONYM TRIGGERS FOR MOAB.TRIGGERS;
CREATE PUBLIC SYNONYM VCS FOR MOAB.VCS;

 
ALTER TABLE MOAB.Nodes MODIFY (
  AvailGres                     VARCHAR2(1024),
  ConfigGres                    VARCHAR2(1024),
  AvailClasses                  VARCHAR2(1024),
  ConfigClasses                 VARCHAR2(1024),
  Features                      VARCHAR2(1024),
  GMetric                       VARCHAR2(1024),
  JobList                       VARCHAR2(1024),
  OldMessages                   VARCHAR2(1024),
  Operations                    VARCHAR2(1024),
  OSList                        VARCHAR2(1024),
  ProvisioningData              VARCHAR2(1024),
  ReservationList               VARCHAR2(1024),
  ResourceManagerList           VARCHAR2(1024),
  VMOSList                      VARCHAR2(1024)
);

ALTER TABLE MOAB.Triggers MODIFY (
  ActionData                    VARCHAR2(1024),
  Description                   VARCHAR2(1024),
  EBuf                          VARCHAR2(1024),
  Flags                         VARCHAR2(1024),
  Message                       VARCHAR2(1024),
  OBuf                          VARCHAR2(1024),
  Requires                      VARCHAR2(1024),
  Sets                          VARCHAR2(1024),
  Unsets                        VARCHAR2(1024)
);

-- Remove Trigger Name from Primary Key by first dropping the PRIMARY KEY
-- and redefining it as just TrigID
ALTER TABLE MOAB.Triggers drop CONSTRAINT Triggers_PK;
ALTER TABLE MOAB.Triggers add CONSTRAINT Triggers_PK PRIMARY KEY (TrigID);
 
ALTER TABLE MOAB.VCs MODIFY (
  Description                   VARCHAR2(1024)
);
-- End changes as of 7.2.6


--========================
-- Create new Moab tables
--========================


--=================================================
-- Add new original Moab triggers/stored procedures
--=================================================
