-- This PostgreSQL script alters Moab 7.2 tables to the current Moab version for all Moab suites and
-- may add additional definition information.
--   Moab HPC Suite - Basic Edition
--   Moab HPC Suite - Enterprise Edition
--   Moab Cloud Suite
--
-- The script is organized into three sections.
--   Deletions
--   Alterations
--   Additions
--====================================================================================================
-- PostgreSQL DBA: Assign the "Moab" user name the additional "RESOURCE" and "DBA" permissions.  Log in
-- with the Moab user name and execute the following DDL statements to update the Moab database from
-- the version contained in this script's file name to the current version, then remove the "DBA" and
-- "RESOURCE" permissions from the "Moab" user name to prevent inadvertant alteration of the "Moab"
-- schema.
--
-- This script is for your convenience in updating the Moab database to the current Moab version.
--
-- If you have added your own custom indexes and/or foreign key definitions to the Moab database for
-- performance purposes for your own use cases, check the DDL and DML statements below to verify they
-- will not interfere with your custom alterations.  If they will, adjust the statements below or add
-- DDL statements for your own alterations to accommodate the Moab modifications below.
--
-- You cannot remove new column or table definitions since the Moab product will require them!
--
-- If you want to retain deleted obsolete columns or tables, be aware you are responsible to maintain
-- them from this point on since the Moab product will not be aware of their presence!


--===================================
-- Drop obsolete Moab procedures/triggers
--===================================


--==================================
-- Drop obsolete Moab table indexes
--==================================


--===========================
-- Drop obsolete Moab tables
--===========================


--=============================================
-- Delete obsolete pre-defined Moab definitions
--=============================================


--=================================================================
-- Alter existing Moab tables to match current version definitions
--=================================================================
-- Begin changes as of 7.2.6
ALTER TABLE nodes
  ALTER COLUMN availgres           TYPE varchar(1024),
  ALTER COLUMN configgres          TYPE varchar(1024),
  ALTER COLUMN availclasses        TYPE varchar(1024),
  ALTER COLUMN configclasses       TYPE varchar(1024),
  ALTER COLUMN features            TYPE varchar(1024),
  ALTER COLUMN gmetric             TYPE varchar(1024),
  ALTER COLUMN joblist             TYPE varchar(1024),
  ALTER COLUMN oldmessages         TYPE varchar(1024),
  ALTER COLUMN operations          TYPE varchar(1024),
  ALTER COLUMN oslist              TYPE varchar(1024),
  ALTER COLUMN provisioningdata    TYPE varchar(1024),
  ALTER COLUMN reservationlist     TYPE varchar(1024),
  ALTER COLUMN resourcemanagerlist TYPE varchar(1024),
  ALTER COLUMN vmoslist            TYPE varchar(1024);

ALTER TABLE triggers
  ALTER COLUMN actiondata          TYPE varchar(1024),
  ALTER COLUMN description         TYPE varchar(1024),
  ALTER COLUMN ebuf                TYPE varchar(1024),
  ALTER COLUMN flags               TYPE varchar(1024),
  ALTER COLUMN message             TYPE varchar(1024),
  ALTER COLUMN obuf                TYPE varchar(1024),
  ALTER COLUMN requires            TYPE varchar(1024),
  ALTER COLUMN sets                TYPE varchar(1024),
  ALTER COLUMN unsets              TYPE varchar(1024);

-- Remove Trigger Name from Primary Key by first dropping the PRIMARY KEY
-- and redefining it as just TrigID
ALTER TABLE triggers DROP CONSTRAINT triggers_pkey;
ALTER TABLE ONLY triggers add CONSTRAINT triggers_pkey PRIMARY KEY (trigid);
 
ALTER TABLE VCs 
  ALTER COLUMN Description         TYPE varchar(1024);
-- End changes as of 7.2.6


--========================
-- Create new Moab tables
--========================


--=================================================
-- Add new original Moab triggers/stored procedures
--=================================================
